pub struct FormatElement { /* private fields */ }Expand description
A formattable element.
Implementations
Sourceimpl FormatElement
impl FormatElement
Sourcepub fn new(
element: Element,
children: Option<NonEmpty<Box<FormatElement>>>,
) -> Self
pub fn new( element: Element, children: Option<NonEmpty<Box<FormatElement>>>, ) -> Self
Creates a new FormatElement.
Sourcepub fn children(
&self,
) -> Option<AssertConsumedIter<impl Iterator<Item = &FormatElement>>>
pub fn children( &self, ) -> Option<AssertConsumedIter<impl Iterator<Item = &FormatElement>>>
Gets the children for this node.
Sourcepub fn has_comment(&self) -> bool
pub fn has_comment(&self) -> bool
Returns true if the underlying syntax for element contains a comment
token (in case of a node) or has inline or preceding trivia (in case of
a token).
FormatElement collation drops trivia, so this peeks at the raw syntax
instead.