TriviaBlankLineSpacingPolicy

Enum TriviaBlankLineSpacingPolicy 

pub enum TriviaBlankLineSpacingPolicy {
    RemoveTrailingBlanks,
    Always,
}
The policy for Trivia::BlankLine line spacing.

Blank lines before comments and between comments are always permitted.

Variants



RemoveTrailingBlanks

Blank lines are allowed before and between comments, but not after.

e.g. a comment, then a blank line, then code, followed by another blank line, would have the trailing blank (between the comment and the code) removed but any blank line before the comment would be preserved.



Always

Blank lines are always allowed.