pub fn format_enum_definition(
element: &FormatElement,
stream: &mut TokenStream<PreToken>,
)Expand description
Formats an EnumDefinition.
Panics
This will panic if the element does not have the expected children.
pub fn format_enum_definition(
element: &FormatElement,
stream: &mut TokenStream<PreToken>,
)Formats an EnumDefinition.
This will panic if the element does not have the expected children.