pub fn format_equality_expr(
element: &FormatElement,
stream: &mut TokenStream<PreToken>,
)Expand description
Formats an EqualityExpr.
Panics
This will panic if the element does not have the expected children.
pub fn format_equality_expr(
element: &FormatElement,
stream: &mut TokenStream<PreToken>,
)Formats an EqualityExpr.
This will panic if the element does not have the expected children.