pub fn format_command_section(
element: &FormatElement,
stream: &mut TokenStream<PreToken>,
)Expand description
Formats a CommandSection.
Panics
This will panic if the element does not have the expected children.
pub fn format_command_section(
element: &FormatElement,
stream: &mut TokenStream<PreToken>,
)Formats a CommandSection.
This will panic if the element does not have the expected children.