pub fn format_conditional_statement(
element: &FormatElement,
stream: &mut TokenStream<PreToken>,
)Expand description
Formats a ConditionalStatement.
Panics
This will panic if the element does not have the expected children.
pub fn format_conditional_statement(
element: &FormatElement,
stream: &mut TokenStream<PreToken>,
)Formats a ConditionalStatement.
This will panic if the element does not have the expected children.