pub enum TriviaBlankLineSpacingPolicy {
RemoveTrailingBlanks,
Always,
}Expand description
The policy for Trivia::BlankLine line spacing.
Blank lines before comments and between comments are always permitted.
Variants
RemoveTrailingBlanks
Blank lines are allowed before and between comments, but not after.
i.e. a comment, then a blank line, then code, would have the blank removed.
Always
Blank lines are always allowed.