pub fn format_equality_expr(
element: &FormatElement,
stream: &mut TokenStream<PreToken>,
config: &Config,
)Expand description
Formats an EqualityExpr.
Panics
This will panic if the element does not have the expected children.
pub fn format_equality_expr(
element: &FormatElement,
stream: &mut TokenStream<PreToken>,
config: &Config,
)Formats an EqualityExpr.
This will panic if the element does not have the expected children.